Struct ndk::configuration::Configuration [−][src]
pub struct Configuration { /* fields omitted */ }Expand description
A native AConfiguration *.
This stores information about configuration. See the NDK docs
Implementations
Construct a Configuration from a pointer.
Safety
By calling this function, you assert that it is a valid pointer to a native
AConfiguration, and give ownership of it to the Configuration instance.
Create a new Configuration, with the same contents as the AConfiguration referenced by
the pointer.
This is useful if you have a pointer, but not ownership of it.
Safety
By calling this function, you assert that it is a valid pointer to a native
AConfiguration.
The pointer to the native AConfiguration. Keep in mind that the Configuration object
still has ownership, and will free it when dropped.
Information about what fields differ between the two configurations
Returns false if anything in self conflicts with requested
Returns the screen density in dpi.
On some devices it can return values outside of the density enum.
Returns keyboard visibility/availability.
Returns the language, as a String of two characters, if a language is set
Returns the layout direction